# Google Cloud Platform Modeling Best Practices
This modeling guide offers best practices for modeling the services of the Google Cloud Platform (GCP) as an IaaS solution.
Infrastructure-as-a-Service (IaaS) is a service model that delivers computer infrastructure on an outsourced basis to support enterprise operations. Typically, IaaS provides hardware, storage, servers, and data center space or network components. The following diagrams show an example of how to model services of the Google Cloud Platform as an IaaS solution in SAP LeanIX.
In this case, a sample web application called “GCP web application” uses several IT components, which represent popular services of GCP. Each IT component is connected to its respective Technology Stack and the Provider. As an example, we see that “GCP web application” uses the service "Google Cloud Dataflow" for data analytics and virtualization purposes. The first model shows the Technology Stacks on its lowest hierarchy level, while the second model uses the SAP LeanIX roll-up functionality, which shows the full hierarchy of the Technology Stacks.
![1904](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751f1627a441014a498bc7ad94fafce_LowRes.png)![1908](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749bf167a4410149149c9a87943c3b5_LowRes.png)
YesNo
Send
